@@ -12,7 +12,7 @@ use base qw( Device::Chip );
 
 use utf8;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 use Data::Bitfield qw( bitfield boolfield enumfield );
@@ -36,24 +36,25 @@ concepts or features, only the use of this module to access them.
 
 =cut
 
-sub new
-{
-   my $class = shift;
-   my %opts = @_;
+=head1 MOUNT PARAMETERS
 
-   my $self = $class->SUPER::new( @_ );
+=head2 addr
 
-   $self->{$_} = $opts{$_} for qw( address );
+The I²C address of the device. Can be specified in decimal, octal or hex with
+leading C<0> or C<0x> prefixes.
 
-   return $self;
-}
+=cut
 
 sub I2C_options
 {
    my $self = shift;
+   my %params = @_;
+
+   my $addr = delete $params{addr} // 0x40;
+   $addr = oct $addr if $addr =~ m/^0/;
 
    return (
-      addr        => $self->{address},
+      addr        => $addr,
       max_bitrate => 100E3,
    );
 }
